@@ -43,7 +43,7 @@ class SeriesParser(TitleParser):
         '(\d{1,3})\s?of\s?(?:\d{1,3})',
         '(?:episode|ep|part|pt)\s?(\d{1,3}|%s)' % roman_numeral_re,
         'part\s(%s)' % '|'.join(map(str, english_numbers))]])
-    unwanted_ep_regexps = ReList([
+    unwanted_regexps = ReList([
         '(\d{1,3})\s?x\s?(0+)[^1-9]',  # 5x0
         'S(\d{1,3})D(\d{1,3})',  # S3D1
         '(\d{1,3})\s?x\s?(all)',  # 1xAll
@@ -58,9 +58,8 @@ class SeriesParser(TitleParser):
     sequence_regexps = ReList([TitleParser.re_not_in_word(regexp) for regexp in [
         '(\d{1,3})(?:v(?P<version>\d))?',
         '(?:pt|part)\s?(\d+|%s)' % roman_numeral_re]])
+    unwanted_sequence_regexps = ReList(['seasons?\s?\d{1,2}'])
     id_regexps = ReList([])
-    unwanted_id_regexps = ReList([
-        'seasons?\s?\d{1,2}'])
     clean_regexps = ReList(['\[.*?\]', '\(.*?\)'])
     # ignore prefix regexps must be passive groups with 0 or 1 occurrences  eg. (?:prefix)?
     ignore_prefixes = [
@@ -193,11 +192,11 @@ class SeriesParser(TitleParser):
             raise Exception('SeriesParser initialization error, name: %s data: %s' %
                             (repr(self.name), repr(self.data)))
 
-        name = self.remove_dirt(self.name)
-
         # check if data appears to be unwanted (abort)
         if self.parse_unwanted(self.remove_dirt(self.data)):
-            return
+            raise ParseWarning('`{data}` appears to be an episode pack'.format(data=self.data))
+
+        name = self.remove_dirt(self.name)
 
         log.debug('name: %s data: %s', name, self.data)
 
@@ -288,7 +287,8 @@ class SeriesParser(TitleParser):
                 self.id_groups = date_match['match'].groups()
                 self.id_type = 'date'
                 self.valid = True
-                if not self.special or not self.prefer_specials: return
+                if not (self.special and self.prefer_specials):
+                    return
             else:
                 log.debug('-> no luck with date_regexps')
 
@@ -314,9 +314,10 @@ class SeriesParser(TitleParser):
                     self.episodes = 1
                 self.id_type = 'ep'
                 self.valid = True
-                if not self.special or not self.prefer_specials: return
-
-            else: log.debug('-> no luck with ep_regexps')
+                if not (self.special and self.prefer_specials):
+                    return
+            else:
+                log.debug('-> no luck with ep_regexps')
 
             if self.identified_by == 'ep':
                 # we should be getting season, ep !
@@ -337,11 +338,8 @@ class SeriesParser(TitleParser):
                     self.id_type = 'ep'
                     self.valid = True
                     return
-                else: log.debug('-> no luck with the expect_ep')
-
-        # Ep mode is done, check for unwanted ids
-        if self.parse_unwanted_id(data_stripped):
-            return
+                else:
+                    log.debug('-> no luck with the expect_ep')
 
         # Check id regexps
         if self.identified_by in ['id', 'auto'] and not self.valid:
@@ -352,19 +350,25 @@ class SeriesParser(TitleParser):
                     if self.strict_name:
                         if match.start() > 1:
                             return
-                    id = '-'.join(g for g in match.groups() if g)
-                    if not id:
+                    found_id = '-'.join(g for g in match.groups() if g)
+                    if not found_id:
                         # If match groups were all blank, don't accept this match
                         continue
-                    self.id = id
+                    self.id = found_id
                     self.id_type = 'id'
                     self.valid = True
                     log.debug('found id \'%s\' with regexp \'%s\'', self.id, id_re.pattern)
-                    if not self.special or not self.prefer_specials: return
-                    else: break
+                    if not (self.special and self.prefer_specials):
+                        return
+                    else:
+                        break
             else:
                 log.debug('-> no luck with id_regexps')
 
+        # Other modes are done, check for unwanted sequence ids
+        if self.parse_unwanted_sequence(data_stripped):
+            return
+
         # Check sequences last as they contain the broadest matches
         if self.identified_by in ['sequence', 'auto'] and not self.valid:
             for sequence_re in self.sequence_regexps:
@@ -388,9 +392,12 @@ class SeriesParser(TitleParser):
                     self.id_type = 'sequence'
                     self.valid = True
                     log.debug('found id \'%s\' with regexp \'%s\'', self.id, sequence_re.pattern)
-                    if not self.special or not self.prefer_specials: return
-                    else: break
-            else: log.debug('-> no luck with sequence_regexps')
+                    if not (self.special and self.prefer_specials):
+                        return
+                    else:
+                        break
+            else:
+                log.debug('-> no luck with sequence_regexps')
 
         # No id found, check if this is a special
         if self.special or self.assume_special:
@@ -400,9 +407,10 @@ class SeriesParser(TitleParser):
             self.valid = True
             log.debug('found special, setting id to \'%s\'', self.id)
             return
-        if self.valid: return
+        if self.valid:
+            return
 
-        msg = 'Title `%s` looks like series `%s` but I cannot find ' % (self.data, self.name)
+        msg = 'Title `%s` looks like series `%s` but cannot find ' % (self.data, self.name)
         if self.identified_by == 'auto':
             msg += 'any series numbering.'
         else:
@@ -411,18 +419,18 @@ class SeriesParser(TitleParser):
 
     def parse_unwanted(self, data):
         """Parses data for an unwanted hits. Return True if the data contains unwanted hits."""
-        for ep_unwanted_re in self.unwanted_ep_regexps:
-            match = re.search(ep_unwanted_re, data)
+        for unwanted_re in self.unwanted_regexps:
+            match = re.search(unwanted_re, data)
             if match:
-                log.debug('unwanted regexp %s matched %s', ep_unwanted_re.pattern, match.groups())
+                log.debug('unwanted regexp %s matched %s', unwanted_re.pattern, match.groups())
                 return True
 
-    def parse_unwanted_id(self, data):
+    def parse_unwanted_sequence(self, data):
         """Parses data for an unwanted id hits. Return True if the data contains unwanted hits."""
-        for id_unwanted_re in self.unwanted_id_regexps:
-            match = re.search(id_unwanted_re, data)
+        for seq_unwanted_re in self.unwanted_sequence_regexps:
+            match = re.search(seq_unwanted_re, data)
             if match:
-                log.debug('unwanted id regexp %s matched %s', id_unwanted_re, match.groups())
+                log.debug('unwanted id regexp %s matched %s', seq_unwanted_re, match.groups())
                 return True
 
     def parse_date(self, data):
@@ -466,8 +474,7 @@ class SeriesParser(TitleParser):
                 possdates.sort()
                 # Pick the most recent date if there are ambiguities
                 bestdate = possdates[-1]
-                return {'date': bestdate,
-                        'match': match}
+                return {'date': bestdate, 'match': match}
 
         return False
 
